.. rst-class:: homepage-header

   `Download <http://pypi.python.org/pypi/geotiler>`_
   | `Bugs <https://github.com/wrobell/geotiler/issues>`_
   | `Source Code <https://github.com/wrobell/geotiler>`_

GeoTiler is a library to create maps using tiles from a map provider.

.. note::
   Version 0.20.0 of GeoTiler will change API. Please use::

        geotiler>=0.14.2,<0.20.0

   as your dependency requirement if you need old API.

The main goal of the library is to enable a programmer to create maps using
tiles downloaded from OpenStreetMap, Stamen or other map provider.

The maps can be used by interactive applications or to create data analysis
graphs.

The code is based on `Python port <https://github.com/stamen/modestmaps-py>`_ of
`Modest Maps <http://modestmaps.com/>`_ project, which is
licensed under BSD license. All subsequent changes are licensed under GPL
v3 license.

Table of Contents
-----------------

.. toctree::
   :maxdepth: 3

   intro
   usage
   cmd
   api
   changelog

* :ref:`genindex`
* :ref:`search`

.. vim: sw=4:et:ai
